import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { withKnobs, boolean } from "@storybook/addon-knobs";
import { html } from "lit-html";
import CATEGORIES from "../categories";
import readme from "../../dist/docs/components/dropdown/readme.md";

<Meta title={CATEGORIES.COMPONENTS + "Dropdown"} />

# Dropdown

A Dropdown can contain a list of options. Filtering of options via a text input can be enabled.

<Canvas
    mdxSource={`
    <ui-dropdown label="Dropdown">
        <ui-checkbox-list-item label="test1" value="1"></ui-checkbox-list-item>
        <ui-checkbox-list-item label="test2" value="2"></ui-checkbox-list-item>
        <ui-checkbox-list-item label="test3" value="3"></ui-checkbox-list-item>
    </ui-dropdown>
`}
>
    <Story
        height="180px"
        name="Dropdown"
        parameters={{ decorators: [withKnobs], jest: ["dropdown.e2e.ts"] }}
    >
        {html`
            <ui-dropdown
                ?filterable="${boolean("filterable", false)}"
                label="Dropdown"
            >
                <ui-checkbox-list-item
                    label="test1"
                    value="1"
                ></ui-checkbox-list-item>
                <ui-checkbox-list-item
                    label="test2"
                    value="2"
                ></ui-checkbox-list-item>
                <ui-checkbox-list-item
                    label="test3"
                    value="3"
                ></ui-checkbox-list-item>
            </ui-dropdown>
        `}
    </Story>
</Canvas>

---

## Filterable Dropdown

Setting the `filterable` attribute, activates a search input inside the dropdown.

<Canvas
    mdxSource={`
    <ui-dropdown filterable label="Filterable Dropdown">
        <ui-checkbox-list-item label="abc" value="1"></ui-checkbox-list-item>
        <ui-checkbox-list-item label="def" value="2"></ui-checkbox-list-item>
        <ui-checkbox-list-item label="abx" value="3"></ui-checkbox-list-item>
    </ui-dropdown>
`}
>
    <Story height="180px" name="Filterable Dropdown">
        {html`
            <ui-dropdown filterable label="Filterable Dropdown">
                <ui-checkbox-list-item
                    label="abc"
                    value="1"
                ></ui-checkbox-list-item>
                <ui-checkbox-list-item
                    label="def"
                    value="2"
                ></ui-checkbox-list-item>
                <ui-checkbox-list-item
                    label="abx"
                    value="3"
                ></ui-checkbox-list-item>
            </ui-dropdown>
        `}
    </Story>
</Canvas>

# Developer Documentation

<Description markdown={readme} />
